aliases = {
    ":+1:": ":thumbsup:",
    ":+1_tone1:": ":thumbsup_tone1:",
    ":+1_tone2:": ":thumbsup_tone2:",
    ":+1_tone3:": ":thumbsup_tone3:",
    ":+1_tone4:": ":thumbsup_tone4:",
    ":+1_tone5:": ":thumbsup_tone5:",
    ":-1:": ":thumbsdown:",
    ":-1_tone1:": ":thumbsdown_tone1:",
    ":-1_tone2:": ":thumbsdown_tone2:",
    ":-1_tone3:": ":thumbsdown_tone3:",
    ":-1_tone4:": ":thumbsdown_tone4:",
    ":-1_tone5:": ":thumbsdown_tone5:",
    ":abandon:": ":wastebasket:",
    ":ability:": ":superhero:",
    ":able:": ":juggling:",
    ":abnormal:": ":flying_saucer:",
    ":aboard:": ":ship:",
    ":abolish:": ":no_good:",
    ":abortion:": ":pregnant_woman:",
    ":about:": ":mag_right:",
    ":abroad:": ":airplane_colorful:",
    ":abrupt:": ":ab:",
    ":absolute:": ":ab:",
    ":absolutely:": ":ab:",
    ":absorb:": ":ab:",
    ":abstract:": ":infinity:",
    ":absurd:": ":black_joker:",
    ":abundance:": ":moneybag:",
    ":abundant:": ":money_with_wings:",
    ":abuse:": ":symbols_on_mouth:",
    ":ac:": ":flag_ac:",
    ":academic:": ":student:",
    ":academy:": ":school:",
    ":accelerate:": ":rocket:",
    ":acceleration:": ":dash:",
    ":accent:": ":speech_left:",
    ":acceptable:": ":accept:",
    ":acceptance:": ":ok_woman_tone1:",
    ":access:": ":key:",
    ":accessory:": ":ninja:",
    ":accident:": ":ambulance:",
    ":accommodate:": ":homes:",
    ":accommodation:": ":hotel:",
    ":accompany:": ":two_women_holding_hands:",
    ":accomplish:": ":trophy:",
    ":accord:": ":handshake:",
    ":accordance:": ":dancers:",
    ":account:": ":ledger:",
    ":accumulate:": ":moneybag:",
    ":accuracy:": ":dart:",
    ":accurate:": ":100:",
    ":accuse:": ":index_pointing_at_the_viewer:",
    ":ache:": ":head_bandage:",
    ":achieve:": ":trophy:",
    ":achievement:": ":trophy:",
    ":acid:": ":test_tube:",
    ":acquaint:": ":information_source:",
    ":acquaintance:": ":confetti_ball:",
    ":acquire:": ":ideograph_advantage:",
    ":act:": ":performing_arts:",
    ":action:": ":clapper:",
    ":activity:": ":cartwheel:",
    ":actor:": ":man_singer:",
    ":actress:": ":woman_singer:",
    ":acute:": ":pushpin:",
    ":ad:": ":newspaper:",
    ":addition:": ":heavy_plus_sign:",
    ":address:": ":round_pushpin:",
    ":administration:": ":office:",
    ":admission:": ":tickets:",
    ":admission_tickets:": ":tickets:",
    ":adolescent:": ":boy:",
    ":adore:": ":star_struck:",
    ":adult:": ":office_worker_tone1:",
    ":advance:": ":fast_forward:",
    ":advantage:": ":white_check_mark:",
    ":adventure:": ":parachute:",
    ":advertisement:": ":newspaper:",
    ":advice:": ":bulb:",
    ":advisable:": ":owl:",
    ":ae:": ":flag_ae:",
    ":aeroplane:": ":airplane_departure:",
    ":af:": ":flag_af:",
    ":affair:": ":office:",
    ":affection:": ":smiling_face_with_hearts:",
    ":afraid:": ":fearful:",
    ":africa:": ":earth_africa:",
    ":african:": ":woman_tone5:",
    ":ag:": ":flag_ag:",
    ":again:": ":repeat_one:",
    ":against:": ":wrestlers_tone5:",
    ":ago:": ":back:",
    ":agreeable:": ":handshake:",
    ":ahead:": ":fast_forward:",
    ":ai:": ":flag_ai:",
    ":air:": ":dash:",
    ":aircraft:": ":airplane_small:",
    ":airline:": ":airplane_small:",
    ":airport:": ":airplane_departure:",
    ":al:": ":flag_al:",
    ":alarm:": ":rotating_light:",
    ":album:": ":minidisc:",
    ":alcohol:": ":beers:",
    ":alive:": ":person_with_blond_hair_tone1:",
    ":along:": ":palm_up_hand:",
    ":aloud:": ":loud_sound:",
    ":alphabet:": ":capital_abcd:",
    ":also:": ":paperclips:",
    ":alternate:": ":arrows_counterclockwise:",
    ":always:": ":repeat:",
    ":america:": ":flag_us:",
    ":american:": ":flag_us:",
    ":ammunition:": ":bomb:",
    ":amplify:": ":mega:",
    ":amuse:": ":juggling:",
    ":ancestor:": ":yin_yang:",
    ":ancient:": ":scroll:",
    ":animal:": ":dog2:",
    ":announcer:": ":womens:",
    ":anonymous:": ":bust_in_silhouette:",
    ":another:": ":twisted_rightwards_arrows:",
    ":answer:": ":dart:",
    ":any:": ":game_die:",
    ":anybody:": ":bust_in_silhouette:",
    ":anyone:": ":bust_in_silhouette:",
    ":anyway:": ":shrug:",
    ":anywhere:": ":park:",
    ":ao:": ":flag_ao:",
    ":apology:": ":bow:",
    ":apparatus:": ":microscope:",
    ":appease:": ":shushing_face:",
    ":applaud:": ":clap:",
    ":aq:": ":flag_aq:",
    ":ar:": ":flag_ar:",
    ":arabian:": ":man_with_turban:",
    ":archery:": ":bow_and_arrow:",
    ":arena:": ":stadium:",
    ":arithmetic:": ":1234:",
    ":arm:": ":muscle:",
    ":armor:": ":shield:",
    ":armour:": ":shield:",
    ":around:": ":globe_with_meridians:",
    ":arrow:": ":arrow_right:",
    ":as:": ":loop:",
    ":asia:": ":earth_asia:",
    ":asian:": ":girl_tone2:",
    ":ask:": ":speaking_head:",
    ":asleep:": ":sleeping:",
    ":associate:": ":paperclips:",
    ":association:": ":teacher_woman:",
    ":assurance:": ":bookmark_tabs:",
    ":astonish:": ":astonished:",
    ":astronomy:": ":telescope:",
    ":athlete:": ":handball:",
    ":atlantic:": ":ocean:",
    ":atlas:": ":map:",
    ":atmosphere:": ":fog:",
    ":atom_symbol:": ":atom:",
    ":attack:": ":fencer:",
    ":aubergine:": ":eggplant:",
    ":aunt:": ":woman_tone1:",
    ":australia:": ":earth_asia:",
    ":australian:": ":flag_au:",
    ":author:": ":writing_hand:",
    ":autumn:": ":fallen_leaf:",
    ":aw:": ":flag_aw:",
    ":away:": ":dash:",
    ":ax:": ":axe:",
    ":az:": ":flag_az:",
    ":ba:": ":flag_ba:",
    ":bachelor:": ":student:",
    ":back_of_hand:": ":raised_back_of_hand:",
    ":back_of_hand_tone1:": ":raised_back_of_hand_tone1:",
    ":back_of_hand_tone2:": ":raised_back_of_hand_tone2:",
    ":back_of_hand_tone3:": ":raised_back_of_hand_tone3:",
    ":back_of_hand_tone4:": ":raised_back_of_hand_tone4:",
    ":back_of_hand_tone5:": ":raised_back_of_hand_tone5:",
    ":backward:": ":rewind:",
    ":bacteria:": ":microbe:",
    ":bad:": ":thumbsdown:",
    ":bag:": ":handbag:",
    ":baggage:": ":luggage:",
    ":baguette_bread:": ":french_bread:",
    ":ball:": ":soccer:",
    ":ballet:": ":ballet_shoes:",
    ":ballot:": ":ballot_box:",
    ":ballot_box_with_ballot:": ":ballot_box:",
    ":bandage:": ":adhesive_bandage:",
    ":banner:": ":flag_white:",
    ":bark:": ":guide_dog:",
    ":bathroom:": ":bath_tone1:",
    ":bb:": ":flag_bb:",
    ":bd:": ":flag_bd:",
    ":be:": ":thought_balloon:",
    ":beach_with_umbrella:": ":beach:",
    ":bean:": ":beans:",
    ":beard:": ":man_with_beard:",
    ":beautiful:": ":hibiscus:",
    ":become:": ":soon:",
    ":bedroom:": ":sleeping_accommodation:",
    ":bedtime:": ":bed:",
    ":beef:": ":cut_of_meat:",
    ":beg:": ":pleading:",
    ":beggar:": ":pleading:",
    ":begin:": ":arrow_forward:",
    ":behind:": ":back:",
    ":bellhop_bell:": ":bellhop:",
    ":belt:": ":martial_arts_uniform:",
    ":best:": ":first_place:",
    ":better:": ":thumbsup:",
    ":between:": ":left_right_arrow:",
    ":beverage:": ":beverage_box:",
    ":bewilder:": ":shrug:",
    ":bf:": ":flag_bf:",
    ":bg:": ":flag_bg:",
    ":bh:": ":flag_bh:",
    ":bi:": ":flag_bi:",
    ":bible:": ":cross:",
    ":bicycle:": ":bike:",
    ":big:": ":elephant:",
    ":bigger:": ":orangutan:",
    ":billion:": ":moneybag:",
    ":biohazard_sign:": ":biohazard:",
    ":biology:": ":petri_dish:",
    ":biscuit:": ":cookie:",
    ":bj:": ":flag_bj:",
    ":bl:": ":flag_bl:",
    ":black:": ":black_heart:",
    ":blackboard:": ":teacher_woman:",
    ":blade:": ":knife:",
    ":blast:": ":boom:",
    ":blaze:": ":fire:",
    ":blink:": ":wink:",
    ":blood:": ":blood_drop:",
    ":blow:": ":wind_blowing_face:",
    ":blue:": ":blue_heart:",
    ":blueberry:": ":blueberries:",
    ":bm:": ":flag_bm:",
    ":bn:": ":flag_bn:",
    ":bo:": ":flag_bo:",
    ":board:": ":placard:",
    ":boat:": ":rowboat:",
    ":body:": ":person_standing:",
    ":booklet:": ":notebook_with_decorative_cover:",
    ":bored:": ":neutral_face:",
    ":boring:": ":yawning:",
    ":born:": ":breast_feeding:",
    ":both:": ":busts_in_silhouette:",
    ":bottle:": ":baby_bottle:",
    ":bottle_with_popping_cork:": ":champagne:",
    ":bounce:": ":skier:",
    ":bowl:": ":bowl_with_spoon:",
    ":box:": ":takeout_box:",
    ":boxing_gloves:": ":boxing_glove:",
    ":bq:": ":flag_bq:",
    ":br:": ":flag_br:",
    ":brave:": ":superhero:",
    ":break:": ":broken_heart:",
    ":breakfast:": ":cooking:",
    ":brew:": ":beer:",
    ":bridge:": ":bridge_at_night:",
    ":bright:": ":star2:",
    ":bring:": ":truck:",
    ":brother:": ":two_men_holding_hands:",
    ":brown:": ":brown_heart:",
    ":brush:": ":paintbrush:",
    ":bs:": ":flag_bs:",
    ":bt:": ":flag_bt:",
    ":bubble:": ":bubbles:",
    ":buck:": ":rabbit2:",
    ":buffalo:": ":water_buffalo:",
    ":build:": ":construction_site:",
    ":building:": ":office:",
    ":building_construction:": ":construction_site:",
    ":bullet:": ":black_circle:",
    ":burn:": ":fire:",
    ":burst:": ":boom:",
    ":bury:": ":headstone:",
    ":busy:": ":technologist_tone1:",
    ":but:": ":point_up:",
    ":butcher:": ":farmer:",
    ":buy:": ":shopping_cart:",
    ":bv:": ":flag_bv:",
    ":bw:": ":flag_bw:",
    ":bye:": ":wave:",
    ":bz:": ":flag_bz:",
    ":cabbage:": ":leafy_green:",
    ":calculate:": ":abacus:",
    ":call:": ":calling:",
    ":call_me_hand:": ":call_me:",
    ":call_me_hand_tone1:": ":call_me_tone1:",
    ":call_me_hand_tone2:": ":call_me_tone2:",
    ":call_me_hand_tone3:": ":call_me_tone3:",
    ":call_me_hand_tone4:": ":call_me_tone4:",
    ":call_me_hand_tone5:": ":call_me_tone5:",
    ":canada:": ":flag_ca:",
    ":canadian:": ":flag_ca:",
    ":cap:": ":billed_cap:",
    ":capital:": ":bank:",
    ":car:": ":blue_car:",
    ":card:": ":identification_card:",
    ":card_file_box:": ":card_box:",
    ":card_index_dividers:": ":dividers:",
    ":careful:": ":warning:",
    ":carefully:": ":warning:",
    ":carpenter:": ":construction_worker:",
    ":carrier:": ":airplane_small:",
    ":carry:": ":truck:",
    ":castle:": ":european_castle:",
    ":catch:": ":fishing_pole_and_fish:",
    ":cc:": ":flag_cc:",
    ":cf:": ":flag_cf:",
    ":cg:": ":flag_cg:",
    ":ch:": ":flag_ch:",
    ":chain:": ":chains:",
    ":chamber:": ":door:",
    ":change:": ":currency_exchange:",
    ":chapter:": ":book:",
    ":character:": ":superhero:",
    ":cheer:": ":partying:",
    ":cheese_wedge:": ":cheese:",
    ":chemist:": ":scientist_woman_tone1:",
    ":chemistry:": ":alembic:",
    ":cherry:": ":cherries:",
    ":chess:": ":chess_pawn:",
    ":chile:": ":flag_cl:",
    ":china:": ":flag_cn:",
    ":chinese:": ":flag_cn:",
    ":chips:": ":fries:",
    ":chocolate:": ":chocolate_bar:",
    ":christian:": ":person_kneeling:",
    ":christmas:": ":christmas_tree:",
    ":ci:": ":flag_ci:",
    ":cigarette:": ":smoking:",
    ":circle:": ":o:",
    ":city:": ":cityscape:",
    ":city_sunrise:": ":city_sunset:",
    ":ck:": ":flag_ck:",
    ":class:": ":teacher_woman_tone1:",
    ":classmate:": ":student:",
    ":classroom:": ":school:",
    ":clean:": ":broom:",
    ":clear:": ":window:",
    ":clever:": ":bulb:",
    ":climb:": ":person_climbing:",
    ":clinking_glass:": ":champagne_glass:",
    ":clockwise:": ":arrows_clockwise:",
    ":close:": ":lock:",
    ":cloth:": ":necktie:",
    ":clothes:": ":kimono:",
    ":cloud_with_lightning:": ":cloud_lightning:",
    ":cloud_with_rain:": ":cloud_rain:",
    ":cloud_with_snow:": ":cloud_snow:",
    ":cloud_with_tornado:": ":cloud_tornado:",
    ":cloudy:": ":cloud:",
    ":clown_face:": ":clown:",
    ":club:": ":stadium:",
    ":cm:": ":flag_cm:",
    ":cn:": ":flag_cn:",
    ":co:": ":flag_co:",
    ":cock:": ":rooster:",
    ":cola:": ":cup_with_straw:",
    ":collect:": ":moneybag:",
    ":color:": ":rainbow:",
    ":come:": ":runner:",
    ":commander:": ":guardsman:",
    ":conductor:": ":womens:",
    ":confuse:": ":confused:",
    ":congo:": ":flag_cd:",
    ":container:": ":package:",
    ":cook:": ":cooking:",
    ":copper:": ":third_place:",
    ":correct:": ":white_check_mark:",
    ":couch_and_lamp:": ":couch:",
    ":cough:": ":sneezing_face:",
    ":counter:": ":abacus:",
    ":country:": ":map:",
    ":countryside:": ":houses:",
    ":couple_with_heart_mm:": ":couple_mm:",
    ":couple_with_heart_ww:": ":couple_ww:",
    ":couplekiss_mm:": ":kiss_mm:",
    ":couplekiss_ww:": ":kiss_ww:",
    ":cousin:": ":bride_with_veil:",
    ":cp:": ":flag_cp:",
    ":cr:": ":flag_cr:",
    ":craft:": ":saw:",
    ":craftsman:": ":mechanic_tone1:",
    ":cricket_bat_ball:": ":cricket:",
    ":crystal:": ":crystal_ball:",
    ":cu:": ":flag_cu:",
    ":cup:": ":trophy:",
    ":customer:": ":man_with_gua_pi_mao:",
    ":cut:": ":scissors:",
    ":cute:": ":girl_tone1:",
    ":cv:": ":flag_cv:",
    ":cw:": ":flag_cw:",
    ":cx:": ":flag_cx:",
    ":cy:": ":flag_cy:",
    ":cylinder:": ":oil:",
    ":cz:": ":flag_cz:",
    ":dad:": ":santa:",
    ":dagger_knife:": ":dagger:",
    ":dance:": ":dancer:",
    ":danger:": ":warning:",
    ":data:": ":floppy_disk:",
    ":daughter:": ":girl:",
    ":dawn:": ":sunrise_over_mountains:",
    ":day:": ":sunny:",
    ":de:": ":flag_de:",
    ":dead:": ":headstone:",
    ":deaf:": ":deaf_woman_tone1:",
    ":dear:": ":heart_exclamation:",
    ":death:": ":headstone:",
    ":deliver:": ":truck:",
    ":delivery:": ":truck:",
    ":dentist:": ":health_worker:",
    ":deny:": ":no_good:",
    ":derelict_house_building:": ":house_abandoned:",
    ":desert_island:": ":island:",
    ":desktop_computer:": ":desktop:",
    ":dg:": ":flag_dg:",
    ":diamond:": ":gem:",
    ":dictionary:": ":book:",
    ":die:": ":skull_crossbones:",
    ":different:": ":bar_chart:",
    ":dig:": ":pick:",
    ":digital:": ":pager:",
    ":dinner:": ":fork_knife_plate:",
    ":direction:": ":compass:",
    ":director:": ":judge:",
    ":dirty:": ":poop:",
    ":disaster:": ":volcano:",
    ":discover:": ":mag_right:",
    ":disguise:": ":disguised:",
    ":disk:": ":cd:",
    ":dislike:": ":thumbsdown:",
    ":divide:": ":heavy_division_sign:",
    ":division:": ":heavy_division_sign:",
    ":dj:": ":flag_dj:",
    ":dk:": ":flag_dk:",
    ":dm:": ":flag_dm:",
    ":do:": ":thought_balloon:",
    ":doctor:": ":health_worker:",
    ":doll:": ":nesting_dolls:",
    ":double_vertical_bar:": ":pause_button:",
    ":dove_of_peace:": ":dove:",
    ":down:": ":point_down:",
    ":downward:": ":chart_with_downwards_trend:",
    ":draw:": ":crayon:",
    ":drawer:": ":file_cabinet:",
    ":drink:": ":coffee:",
    ":drive:": ":oncoming_automobile:",
    ":driver:": ":man_in_tuxedo:",
    ":drool:": ":drooling_face:",
    ":drop:": ":droplet:",
    ":drum_with_drumsticks:": ":drum:",
    ":during:": ":stopwatch:",
    ":dz:": ":flag_dz:",
    ":ea:": ":flag_ea:",
    ":each:": ":wrestlers_tone1:",
    ":early:": ":sunrise_over_mountains:",
    ":earth:": ":earth_asia:",
    ":easily:": ":shushing_face:",
    ":easter:": ":moyai:",
    ":easy:": ":sunglasses:",
    ":eat:": ":fork_knife_plate:",
    ":ec:": ":flag_ec:",
    ":editor:": ":writing_hand:",
    ":ee:": ":flag_ee:",
    ":eg:": ":flag_eg:",
    ":eh:": ":flag_eh:",
    ":either:": ":busts_in_silhouette:",
    ":eject_symbol:": ":eject:",
    ":elbow:": ":mechanical_arm:",
    ":email:": ":e-mail:",
    ":embrace:": ":people_hugging:",
    ":emperor:": ":crown:",
    ":employer:": ":office_worker:",
    ":engineer:": ":technologist:",
    ":english:": ":flag_gb:",
    ":enjoy:": ":partying:",
    ":enough:": ":no_good:",
    ":equal:": ":heavy_equals_sign:",
    ":equator:": ":globe_with_meridians:",
    ":er:": ":flag_er:",
    ":error:": ":x:",
    ":es:": ":flag_es:",
    ":et:": ":flag_et:",
    ":eu:": ":flag_eu:",
    ":europe:": ":earth_africa:",
    ":even:": ":city_dusk:",
    ":evening:": ":city_dusk:",
    ":every:": ":100:",
    ":everybody:": ":family_wwgg:",
    ":everyone:": ":family_wwgg:",
    ":everywhere:": ":earth_americas:",
    ":exchange:": ":currency_exchange:",
    ":excited:": ":star_struck:",
    ":exciting:": ":star_struck:",
    ":exercise:": ":lifter:",
    ":expecting_woman:": ":pregnant_woman:",
    ":expecting_woman_tone1:": ":pregnant_woman_tone1:",
    ":expecting_woman_tone2:": ":pregnant_woman_tone2:",
    ":expecting_woman_tone3:": ":pregnant_woman_tone3:",
    ":expecting_woman_tone4:": ":pregnant_woman_tone4:",
    ":expecting_woman_tone5:": ":pregnant_woman_tone5:",
    ":extinguish:": ":fire_extinguisher:",
    ":face_with_cowboy_hat:": ":cowboy:",
    ":face_with_head_bandage:": ":head_bandage:",
    ":face_with_rolling_eyes:": ":rolling_eyes:",
    ":face_with_thermometer:": ":thermometer_face:",
    ":facepalm:": ":face_palm:",
    ":facepalm_tone1:": ":face_palm_tone1:",
    ":facepalm_tone2:": ":face_palm_tone2:",
    ":facepalm_tone3:": ":face_palm_tone3:",
    ":facepalm_tone4:": ":face_palm_tone4:",
    ":facepalm_tone5:": ":face_palm_tone5:",
    ":fall:": ":fallen_leaf:",
    ":famous:": ":superhero:",
    ":fantastic:": ":sparkles:",
    ":far:": ":airplane_departure:",
    ":farewell:": ":wave:",
    ":farm:": ":farmer:",
    ":farther:": ":satellite:",
    ":fast:": ":rocket:",
    ":fat:": ":pig2:",
    ":father:": ":santa:",
    ":favourite:": ":heart_eyes:",
    ":feel:": ":blush:",
    ":fencing:": ":fencer:",
    ":fertilizer:": ":poop:",
    ":festival:": ":gift:",
    ":fever:": ":hot_face:",
    ":fi:": ":flag_fi:",
    ":film:": ":projector:",
    ":film_projector:": ":projector:",
    ":filter:": ":alembic:",
    ":finally:": ":end:",
    ":find:": ":spy_tone1:",
    ":fine:": ":ok_hand:",
    ":finger:": ":fingers_crossed:",
    ":fireman:": ":firefighter:",
    ":firework:": ":fireworks:",
    ":first_place_medal:": ":first_place:",
    ":fit:": ":person_in_lotus_position_tone1:",
    ":fj:": ":flag_fj:",
    ":fk:": ":flag_fk:",
    ":flag:": ":triangular_flag_on_post:",
    ":flame:": ":fire:",
    ":flan:": ":custard:",
    ":floor:": ":footprints:",
    ":flower:": ":bouquet:",
    ":fm:": ":flag_fm:",
    ":fo:": ":flag_fo:",
    ":follow:": ":point_right:",
    ":food:": ":stew:",
    ":football:": ":soccer:",
    ":footprint:": ":footprints:",
    ":footstep:": ":footprints:",
    ":foreigner:": ":mens:",
    ":forest:": ":deciduous_tree:",
    ":forever:": ":infinity:",
    ":fork:": ":fork_and_knife:",
    ":fork_and_knife_with_plate:": ":fork_knife_plate:",
    ":foster:": ":pregnant_woman:",
    ":fox_face:": ":fox:",
    ":fr:": ":flag_fr:",
    ":frame_with_picture:": ":frame_photo:",
    ":fresh:": ":herb:",
    ":friend:": ":two_women_holding_hands:",
    ":from:": ":incoming_envelope:",
    ":front:": ":index_pointing_at_the_viewer:",
    ":frontier:": ":passport_control:",
    ":fruit:": ":kiwi:",
    ":fun:": ":carousel_horse:",
    ":funeral_urn:": ":urn:",
    ":funny:": ":zany_face:",
    ":further:": ":satellite:",
    ":future:": ":crystal_ball:",
    ":ga:": ":flag_ga:",
    ":gamble:": ":game_die:",
    ":game:": ":video_game:",
    ":garbage:": ":do_not_litter:",
    ":garden:": ":house_with_garden:",
    ":gardener:": ":farmer:",
    ":garment:": ":coat:",
    ":gatekeeper:": ":guardsman_tone1:",
    ":gay_pride_flag:": ":rainbow_flag:",
    ":gb:": ":flag_gb:",
    ":gd:": ":flag_gd:",
    ":ge:": ":flag_ge:",
    ":gently:": ":man_in_tuxedo_tone1:",
    ":gesture:": ":love_you_gesture:",
    ":get:": ":inbox_tray:",
    ":gf:": ":flag_gf:",
    ":gg:": ":flag_gg:",
    ":gh:": ":flag_gh:",
    ":gi:": ":flag_gi:",
    ":giant:": ":troll:",
    ":giggle:": ":hand_over_mouth:",
    ":gl:": ":flag_gl:",
    ":glass:": ":jar:",
    ":glass_of_milk:": ":milk:",
    ":glasses:": ":eyeglasses:",
    ":glitter:": ":sparkles:",
    ":glove:": ":gloves:",
    ":glue:": ":lotion_bottle:",
    ":gm:": ":flag_gm:",
    ":gn:": ":flag_gn:",
    ":go:": ":runner:",
    ":goal_net:": ":goal:",
    ":gold:": ":first_place:",
    ":good:": ":thumbsup:",
    ":goodbye:": ":wave:",
    ":governor:": ":judge:",
    ":gp:": ":flag_gp:",
    ":gq:": ":flag_gq:",
    ":gr:": ":flag_gr:",
    ":grade:": ":100:",
    ":graduate:": ":student:",
    ":granddaughter:": ":child:",
    ":grandfather:": ":older_man:",
    ":grandma:": ":older_woman:",
    ":grandma_tone1:": ":older_woman_tone1:",
    ":grandma_tone2:": ":older_woman_tone2:",
    ":grandma_tone3:": ":older_woman_tone3:",
    ":grandma_tone4:": ":older_woman_tone4:",
    ":grandma_tone5:": ":older_woman_tone5:",
    ":grandmother:": ":older_woman:",
    ":grandpa:": ":older_man:",
    ":grandparent:": ":older_man:",
    ":grape:": ":grapes:",
    ":grass:": ":shamrock:",
    ":great:": ":hugging:",
    ":green:": ":green_heart:",
    ":green_salad:": ":salad:",
    ":grocer:": ":convenience_store:",
    ":ground:": ":earth_asia:",
    ":grow:": ":seedling:",
    ":gs:": ":flag_gs:",
    ":gt:": ":flag_gt:",
    ":gu:": ":flag_gu:",
    ":guard:": ":guardsman:",
    ":gunpowder:": ":firecracker:",
    ":gw:": ":flag_gw:",
    ":gy:": ":flag_gy:",
    ":hair:": ":curly_hair:",
    ":half:": ":first_quarter_moon:",
    ":hall:": ":classical_building:",
    ":hammer_and_pick:": ":hammer_pick:",
    ":hammer_and_wrench:": ":tools:",
    ":hand:": ":raised_hand:",
    ":hand_with_index_and_middle_finger_crossed:": ":fingers_crossed:",
    ":hand_with_index_and_middle_fingers_crossed_tone1:": ":fingers_crossed_tone1:",
    ":hand_with_index_and_middle_fingers_crossed_tone2:": ":fingers_crossed_tone2:",
    ":hand_with_index_and_middle_fingers_crossed_tone3:": ":fingers_crossed_tone3:",
    ":hand_with_index_and_middle_fingers_crossed_tone4:": ":fingers_crossed_tone4:",
    ":hand_with_index_and_middle_fingers_crossed_tone5:": ":fingers_crossed_tone5:",
    ":handbook:": ":book:",
    ":handsome:": ":man_in_tuxedo:",
    ":handwriting:": ":writing_hand:",
    ":hankey:": ":poop:",
    ":happily:": ":grin:",
    ":happy:": ":blush:",
    ":hard:": ":triumph:",
    ":hat:": ":womans_hat:",
    ":hate:": ":rage:",
    ":have:": ":palm_up_hand:",
    ":he:": ":handball:",
    ":head:": ":person:",
    ":headache:": ":exploding_head:",
    ":headmaster:": ":teacher_tone1:",
    ":headquarters:": ":office:",
    ":healthy:": ":salad:",
    ":hear:": ":deaf_aid:",
    ":heat:": ":fire:",
    ":heavy:": ":lifter:",
    ":heavy_heart_exclamation_mark_ornament:": ":heart_exclamation:",
    ":hello:": ":raising_hand:",
    ":helmet:": ":military_helmet:",
    ":helmet_with_white_cross:": ":helmet_with_cross:",
    ":help:": ":sos:",
    ":her:": ":handball_girl:",
    ":here:": ":point_down:",
    ":hero:": ":superhero:",
    ":heroine:": ":woman_superhero:",
    ":hers:": ":handball_girl:",
    ":herself:": ":handball_girl:",
    ":hi:": ":raising_hand:",
    ":high:": ":top:",
    ":hill:": ":mountain:",
    ":him:": ":handball:",
    ":himself:": ":handball:",
    ":hippopotamus:": ":hippo:",
    ":his:": ":handball:",
    ":hit:": ":punch:",
    ":hk:": ":flag_hk:",
    ":hm:": ":flag_hm:",
    ":hn:": ":flag_hn:",
    ":hobby:": ":joystick:",
    ":holiday:": ":tada:",
    ":home:": ":house:",
    ":homework:": ":pencil:",
    ":honey:": ":honey_pot:",
    ":honeybee:": ":bee:",
    ":horn:": ":unicorn:",
    ":horror:": ":skull_crossbones:",
    ":hot:": ":fire:",
    ":hot_dog:": ":hotdog:",
    ":hour:": ":clock12:",
    ":house_buildings:": ":homes:",
    ":how:": ":question:",
    ":hr:": ":flag_hr:",
    ":ht:": ":flag_ht:",
    ":hu:": ":flag_hu:",
    ":hug:": ":people_hugging:",
    ":hugging_face:": ":hugging:",
    ":hum:": ":bee:",
    ":hundred:": ":100:",
    ":hunger:": ":drooling_face:",
    ":hungry:": ":drooling_face:",
    ":hurl:": ":handball:",
    ":hurt:": ":broken_heart:",
    ":i:": ":person_in_lotus_position_tone1:",
    ":ic:": ":flag_ic:",
    ":ice-cream:": ":ice_cream:",
    ":ie:": ":flag_ie:",
    ":il:": ":flag_il:",
    ":ill:": ":thermometer_face:",
    ":im:": ":flag_im:",
    ":important:": ":exclamation:",
    ":incorrect:": ":negative_squared_cross_mark:",
    ":indian:": ":flag_in:",
    ":indonesia:": ":flag_id:",
    ":ink:": ":pen_fountain:",
    ":interesting:": ":thinking:",
    ":interpreter:": ":mens:",
    ":invent:": ":bulb:",
    ":invention:": ":bulb:",
    ":inventor:": ":scientist_tone1:",
    ":io:": ":flag_io:",
    ":iq:": ":flag_iq:",
    ":ir:": ":flag_ir:",
    ":it:": ":teddy:",
    ":italian:": ":flag_it:",
    ":its:": ":teddy:",
    ":itself:": ":teddy:",
    ":jack-o'-lantern:": ":jack_o_lantern:",
    ":je:": ":flag_je:",
    ":jm:": ":flag_jm:",
    ":jo:": ":flag_jo:",
    ":job:": ":briefcase:",
    ":join:": ":link:",
    ":journalist:": ":womens:",
    ":journey:": ":map:",
    ":jp:": ":flag_jp:",
    ":juggle:": ":juggling:",
    ":juggler:": ":juggling:",
    ":juggler_tone1:": ":juggling_tone1:",
    ":juggler_tone2:": ":juggling_tone2:",
    ":juggler_tone3:": ":juggling_tone3:",
    ":juggler_tone4:": ":juggling_tone4:",
    ":juggler_tone5:": ":juggling_tone5:",
    ":juice:": ":beverage_box:",
    ":jump:": ":cartwheel:",
    ":junior:": ":boy:",
    ":karate_uniform:": ":martial_arts_uniform:",
    ":kayak:": ":canoe:",
    ":ke:": ":flag_ke:",
    ":keep:": ":lock:",
    ":keeper:": ":guardsman:",
    ":keycap_asterisk:": ":asterisk:",
    ":kg:": ":flag_kg:",
    ":kh:": ":flag_kh:",
    ":ki:": ":flag_ki:",
    ":kid:": ":child:",
    ":kill:": ":knife:",
    ":kind:": ":innocent:",
    ":kitchen:": ":woman_cook_tone1:",
    ":kiwifruit:": ":kiwi:",
    ":km:": ":flag_km:",
    ":kn:": ":flag_kn:",
    ":knee:": ":mechanical_leg:",
    ":kneel:": ":person_kneeling:",
    ":know:": ":information_source:",
    ":kp:": ":flag_kp:",
    ":kr:": ":flag_kr:",
    ":kw:": ":flag_kw:",
    ":ky:": ":flag_ky:",
    ":kz:": ":flag_kz:",
    ":la:": ":flag_la:",
    ":lake:": ":park:",
    ":lamp:": ":couch:",
    ":land:": ":island:",
    ":last:": ":end:",
    ":late:": ":soon:",
    ":later:": ":soon:",
    ":latin_cross:": ":cross:",
    ":laugh:": ":smile:",
    ":laughter:": ":rofl:",
    ":lawyer:": ":judge:",
    ":layer:": ":pancakes:",
    ":lazy:": ":weary:",
    ":lb:": ":flag_lb:",
    ":lc:": ":flag_lc:",
    ":leader:": ":man_in_tuxedo:",
    ":leaf:": ":leaves:",
    ":learn:": ":teacher_woman_tone1:",
    ":leather:": ":handbag:",
    ":left:": ":point_left:",
    ":left_fist:": ":left_facing_fist:",
    ":left_fist_tone1:": ":left_facing_fist_tone1:",
    ":left_fist_tone2:": ":left_facing_fist_tone2:",
    ":left_fist_tone3:": ":left_facing_fist_tone3:",
    ":left_fist_tone4:": ":left_facing_fist_tone4:",
    ":left_fist_tone5:": ":left_facing_fist_tone5:",
    ":left_speech_bubble:": ":speech_left:",
    ":lesson:": ":teacher_woman_tone1:",
    ":let:": ":palm_up_hand:",
    ":letter:": ":love_letter:",
    ":lever:": ":joystick:",
    ":li:": ":flag_li:",
    ":liar:": ":lying_face:",
    ":library:": ":school:",
    ":lie:": ":lying_face:",
    ":life:": ":seedling:",
    ":lifeguard:": ":buoy:",
    ":light:": ":bulb:",
    ":like:": ":thumbsup:",
    ":liner:": ":cruise_ship:",
    ":linked_paperclips:": ":paperclips:",
    ":lion:": ":lion_face:",
    ":lip:": ":biting_lip:",
    ":list:": ":receipt:",
    ":listen:": ":deaf_woman_tone1:",
    ":listener:": ":deaf_person:",
    ":litter:": ":put_litter_in_its_place:",
    ":little:": ":pinching_hand:",
    ":live:": ":house_abandoned:",
    ":living-room:": ":couch:",
    ":lk:": ":flag_lk:",
    ":long:": ":straight_ruler:",
    ":look:": ":eyes:",
    ":lost:": ":mag:",
    ":love:": ":cupid:",
    ":lovely:": ":smiling_face_with_hearts:",
    ":lover:": ":couple_mw:",
    ":lower_left_ballpoint_pen:": ":pen_ballpoint:",
    ":lower_left_crayon:": ":crayon:",
    ":lower_left_fountain_pen:": ":pen_fountain:",
    ":lower_left_paintbrush:": ":paintbrush:",
    ":lr:": ":flag_lr:",
    ":ls:": ":flag_ls:",
    ":lt:": ":flag_lt:",
    ":lu:": ":flag_lu:",
    ":lumber:": ":wood:",
    ":lunch:": ":bento:",
    ":lung:": ":lungs:",
    ":lv:": ":flag_lv:",
    ":ly:": ":flag_ly:",
    ":ma:": ":flag_ma:",
    ":machine:": ":slot_machine:",
    ":magazine:": ":closed_book:",
    ":magic:": ":sparkles:",
    ":maize:": ":corn:",
    ":make:": ":wrench:",
    ":male_dancer:": ":man_dancing:",
    ":male_dancer_tone1:": ":man_dancing_tone1:",
    ":male_dancer_tone2:": ":man_dancing_tone2:",
    ":male_dancer_tone3:": ":man_dancing_tone3:",
    ":male_dancer_tone4:": ":man_dancing_tone4:",
    ":male_dancer_tone5:": ":man_dancing_tone5:",
    ":man_in_business_suit_levitating:": ":levitate:",
    ":manager:": ":man_in_tuxedo:",
    ":mantlepiece_clock:": ":clock:",
    ":manufacturer:": ":factory:",
    ":master:": ":student:",
    ":match:": ":couple_mw:",
    ":mathematical:": ":triple_root:",
    ":mathematics:": ":infinity:",
    ":maths:": ":pai:",
    ":matter:": ":atom:",
    ":mayor:": ":judge:",
    ":mc:": ":flag_mc:",
    ":md:": ":flag_md:",
    ":me:": ":person_in_lotus_position_tone1:",
    ":meat:": ":cut_of_meat:",
    ":mechanical:": ":mechanical_leg:",
    ":medicine:": ":pill:",
    ":meet:": ":handshake:",
    ":member:": ":bust_in_silhouette:",
    ":mess:": ":woozy:",
    ":messenger:": ":envelope_with_arrow:",
    ":meter:": ":straight_ruler:",
    ":mf:": ":flag_mf:",
    ":mg:": ":flag_mg:",
    ":mh:": ":flag_mh:",
    ":microcomputer:": ":desktop:",
    ":middle:": ":middle_finger:",
    ":million:": ":moneybag:",
    ":mine:": ":person_in_lotus_position:",
    ":miner:": ":construction_worker:",
    ":minister:": ":office_worker:",
    ":minus:": ":heavy_minus_sign:",
    ":minute:": ":stopwatch:",
    ":miss:": ":person_standing_girl_tone1:",
    ":mister:": ":man:",
    ":mk:": ":flag_mk:",
    ":ml:": ":flag_ml:",
    ":mm:": ":flag_mm:",
    ":mn:": ":flag_mn:",
    ":mo:": ":flag_mo:",
    ":model:": ":dancer_tone1:",
    ":money:": ":moneybag:",
    ":money_mouth_face:": ":money_mouth:",
    ":monitor:": ":desktop:",
    ":monster:": ":space_invader:",
    ":month:": ":calendar_spiral:",
    ":moon:": ":crescent_moon:",
    ":more:": ":heart_eyes:",
    ":morning:": ":sunrise:",
    ":most:": ":top:",
    ":mother:": ":mrs_claus:",
    ":mother_christmas:": ":mrs_claus:",
    ":mother_christmas_tone1:": ":mrs_claus_tone1:",
    ":mother_christmas_tone2:": ":mrs_claus_tone2:",
    ":mother_christmas_tone3:": ":mrs_claus_tone3:",
    ":mother_christmas_tone4:": ":mrs_claus_tone4:",
    ":mother_christmas_tone5:": ":mrs_claus_tone5:",
    ":motor:": ":motorcycle:",
    ":motorbike:": ":motor_scooter:",
    ":move:": ":runner_tone1:",
    ":movie:": ":movie_camera:",
    ":mp:": ":flag_mp:",
    ":mq:": ":flag_mq:",
    ":mr:": ":man_in_tuxedo_tone1:",
    ":mrs:": ":bride_with_veil_tone1:",
    ":ms:": ":woman_in_tuxedo_tone1:",
    ":mt:": ":flag_mt:",
    ":mu:": ":flag_mu:",
    ":multiply:": ":heavy_multiplication_x:",
    ":mum:": ":mrs_claus:",
    ":murder:": ":knife:",
    ":murderer:": ":knife:",
    ":museum:": ":school:",
    ":music:": ":notes:",
    ":musical:": ":musical_note:",
    ":musician:": ":singer:",
    ":mv:": ":flag_mv:",
    ":mw:": ":flag_mw:",
    ":mx:": ":flag_mx:",
    ":my:": ":person_in_lotus_position_tone1:",
    ":myself:": ":person_in_lotus_position:",
    ":mz:": ":flag_mz:",
    ":na:": ":flag_na:",
    ":nail:": ":nail_care:",
    ":national_park:": ":park:",
    ":nc:": ":flag_nc:",
    ":ne:": ":flag_ne:",
    ":near:": ":point_left_tone5:",
    ":neck:": ":scarf:",
    ":neighbour:": ":homes:",
    ":nerd_face:": ":nerd:",
    ":never:": ":no_good:",
    ":next:": ":track_next:",
    ":next_track:": ":track_next:",
    ":nf:": ":flag_nf:",
    ":ni:": ":flag_ni:",
    ":nice:": ":ok_hand:",
    ":nigeria:": ":flag_ng:",
    ":night:": ":night_with_stars:",
    ":nl:": ":flag_nl:",
    ":no:": ":no_good_tone1:",
    ":nobody:": ":no_pedestrians:",
    ":nod:": ":ok_woman_tone1:",
    ":noise:": ":loud_sound:",
    ":noisy:": ":loud_sound:",
    ":none:": ":no_entry_sign:",
    ":nonsense:": ":symbols_on_mouth:",
    ":noodle:": ":ramen:",
    ":noon:": ":clock12:",
    ":northeast:": ":arrow_upper_right:",
    ":northwest:": ":arrow_upper_left:",
    ":not:": ":no_good_tone1:",
    ":note:": ":pencil:",
    ":now:": ":stopwatch:",
    ":np:": ":flag_np:",
    ":nr:": ":flag_nr:",
    ":nu:": ":flag_nu:",
    ":number:": ":1234:",
    ":nursery:": ":baby_bottle:",
    ":nz:": ":flag_nz:",
    ":o'clock:": ":alarm_clock:",
    ":observer:": ":monocle:",
    ":off:": ":mobile_phone_off:",
    ":officer:": ":cop:",
    ":often:": ":calendar:",
    ":oh:": ":scream_cat:",
    ":oil_drum:": ":oil:",
    ":ok:": ":ok_hand:",
    ":okay:": ":ok_hand:",
    ":old:": ":older_woman:",
    ":old_key:": ":key2:",
    ":om:": ":flag_om:",
    ":oneself:": ":person_in_lotus_position:",
    ":online:": ":computer:",
    ":only:": ":cupid:",
    ":open:": ":open_hands:",
    ":operator:": ":mechanic:",
    ":orange:": ":tangerine:",
    ":our:": ":family_mwb:",
    ":ours:": ":family_mwb:",
    ":ourselves:": ":family_mwb:",
    ":outing:": ":camping:",
    ":own:": ":moneybag:",
    ":owner:": ":bust_in_silhouette:",
    ":pa:": ":flag_pa:",
    ":paella:": ":shallow_pan_of_food:",
    ":paint:": ":art:",
    ":painter:": ":artist:",
    ":palace:": ":european_castle:",
    ":palm:": ":palm_tree:",
    ":pancake:": ":pancakes:",
    ":panda:": ":panda_face:",
    ":paper:": ":roll_of_paper:",
    ":parent:": ":family_mwb:",
    ":part:": ":broken_heart:",
    ":partner:": ":couple_mw:",
    ":party:": ":partying:",
    ":passenger:": ":man_with_gua_pi_mao:",
    ":passenger_ship:": ":cruise_ship:",
    ":path:": ":motorway:",
    ":paw_prints:": ":feet:",
    ":pe:": ":basketball_player_tone1:",
    ":pea:": ":beans:",
    ":peace_symbol:": ":peace:",
    ":peanut:": ":peanuts:",
    ":pedestrian:": ":walking:",
    ":peep:": ":peeking_eye:",
    ":pen:": ":pen_fountain:",
    ":penny:": ":coin:",
    ":people:": ":busts_in_silhouette:",
    ":pepper:": ":hot_pepper:",
    ":person_doing_cartwheel:": ":cartwheel:",
    ":person_doing_cartwheel_tone1:": ":cartwheel_tone1:",
    ":person_doing_cartwheel_tone2:": ":cartwheel_tone2:",
    ":person_doing_cartwheel_tone3:": ":cartwheel_tone3:",
    ":person_doing_cartwheel_tone4:": ":cartwheel_tone4:",
    ":person_doing_cartwheel_tone5:": ":cartwheel_tone5:",
    ":person_with_ball:": ":basketball_player:",
    ":person_with_ball_tone1:": ":basketball_player_tone1:",
    ":person_with_ball_tone2:": ":basketball_player_tone2:",
    ":person_with_ball_tone3:": ":basketball_player_tone3:",
    ":person_with_ball_tone4:": ":basketball_player_tone4:",
    ":person_with_ball_tone5:": ":basketball_player_tone5:",
    ":pf:": ":flag_pf:",
    ":pg:": ":flag_pg:",
    ":ph:": ":flag_ph:",
    ":philosopher:": ":teacher_tone1:",
    ":phone:": ":calling:",
    ":photo:": ":frame_photo:",
    ":photograph:": ":frame_photo:",
    ":photographer:": ":camera_with_flash:",
    ":physician:": ":health_worker:",
    ":physicist:": ":scientist:",
    ":physics:": ":telescope:",
    ":piano:": ":musical_keyboard:",
    ":picnic:": ":camping:",
    ":picture:": ":frame_photo:",
    ":piece:": ":jigsaw:",
    ":pigeon:": ":dove:",
    ":pin:": ":safety_pin:",
    ":pinch:": ":pinching_hand:",
    ":pioneer:": ":bust_in_silhouette:",
    ":pirate:": ":pirate_flag:",
    ":pistol:": ":gun:",
    ":pk:": ":flag_pk:",
    ":pl:": ":flag_pl:",
    ":place:": ":round_pushpin:",
    ":plan:": ":pencil:",
    ":plane:": ":airplane:",
    ":planet:": ":ringed_planet:",
    ":plant:": ":potted_plant:",
    ":plastic:": ":bucket:",
    ":plate:": ":fork_knife_plate:",
    ":play:": ":arrow_forward:",
    ":player:": ":wrestlers:",
    ":playground:": ":ferris_wheel:",
    ":plead:": ":pleading:",
    ":please:": ":pleading:",
    ":plug:": ":electric_plug:",
    ":plus:": ":heavy_plus_sign:",
    ":pm:": ":flag_pm:",
    ":pn:": ":flag_pn:",
    ":pod:": ":beans:",
    ":police:": ":cop:",
    ":policeman:": ":cop:",
    ":politician:": ":judge:",
    ":ponder:": ":pensive:",
    ":poo:": ":poop:",
    ":poor:": ":heavy_dollar_sign:",
    ":porter:": ":construction_worker:",
    ":post:": ":postbox:",
    ":poster:": ":placard:",
    ":pot:": ":honey_pot:",
    ":pour:": ":pouring_liquid:",
    ":power:": ":electric_plug:",
    ":powerful:": ":muscle:",
    ":pr:": ":flag_pr:",
    ":praise:": ":clap:",
    ":prayer:": ":pray:",
    ":predict:": ":crystal_ball:",
    ":pregnant:": ":pregnant_woman:",
    ":premier:": ":prince:",
    ":present:": ":gift:",
    ":pretty:": ":princess_tone1:",
    ":previous_track:": ":track_previous:",
    ":primary:": ":key:",
    ":prisoner:": ":levitate:",
    ":professor:": ":teacher:",
    ":project:": ":bar_chart:",
    ":ps:": ":pencil:",
    ":psychiatrist:": ":health_worker:",
    ":pt:": ":flag_pt:",
    ":pudding:": ":custard:",
    ":pupil:": ":student:",
    ":purple:": ":purple_heart:",
    ":put:": ":put_litter_in_its_place:",
    ":puzzle:": ":jigsaw:",
    ":pw:": ":flag_pw:",
    ":py:": ":flag_py:",
    ":qa:": ":flag_qa:",
    ":queen:": ":princess_tone1:",
    ":quickly:": ":rocket:",
    ":quiet:": ":shushing_face:",
    ":race:": ":race_car:",
    ":racing_car:": ":race_car:",
    ":racing_motorcycle:": ":motorcycle:",
    ":radioactive_sign:": ":radioactive:",
    ":radioactivity:": ":radioactive:",
    ":railroad:": ":railway_track:",
    ":railroad_track:": ":railway_track:",
    ":railway:": ":railway_track:",
    ":rain:": ":cloud_rain:",
    ":rainy:": ":cloud_rain:",
    ":raised_hand_with_fingers_splayed:": ":hand_splayed:",
    ":raised_hand_with_fingers_splayed_tone1:": ":hand_splayed_tone1:",
    ":raised_hand_with_fingers_splayed_tone2:": ":hand_splayed_tone2:",
    ":raised_hand_with_fingers_splayed_tone3:": ":hand_splayed_tone3:",
    ":raised_hand_with_fingers_splayed_tone4:": ":hand_splayed_tone4:",
    ":raised_hand_with_fingers_splayed_tone5:": ":hand_splayed_tone5:",
    ":raised_hand_with_part_between_middle_and_ring_fingers:": ":vulcan:",
    ":raised_hand_with_part_between_middle_and_ring_fingers_tone1:": ":vulcan_tone1:",
    ":raised_hand_with_part_between_middle_and_ring_fingers_tone2:": ":vulcan_tone2:",
    ":raised_hand_with_part_between_middle_and_ring_fingers_tone3:": ":vulcan_tone3:",
    ":raised_hand_with_part_between_middle_and_ring_fingers_tone4:": ":vulcan_tone4:",
    ":raised_hand_with_part_between_middle_and_ring_fingers_tone5:": ":vulcan_tone5:",
    ":re:": ":flag_re:",
    ":read:": ":newspaper:",
    ":reader:": ":books:",
    ":receiver:": ":inbox_tray:",
    ":recorder:": ":vhs:",
    ":red:": ":heart:",
    ":refuse:": ":no_good:",
    ":relative:": ":link:",
    ":remember:": ":bulb:",
    ":repeatedly:": ":repeat:",
    ":reporter:": ":microphone:",
    ":researcher:": ":scientist:",
    ":rest:": ":relieved:",
    ":restaurant:": ":fork_knife_plate:",
    ":reuse:": ":recycle:",
    ":reversed_hand_with_middle_finger_extended:": ":middle_finger:",
    ":reversed_hand_with_middle_finger_extended_tone1:": ":middle_finger_tone1:",
    ":reversed_hand_with_middle_finger_extended_tone2:": ":middle_finger_tone2:",
    ":reversed_hand_with_middle_finger_extended_tone3:": ":middle_finger_tone3:",
    ":reversed_hand_with_middle_finger_extended_tone4:": ":middle_finger_tone4:",
    ":reversed_hand_with_middle_finger_extended_tone5:": ":middle_finger_tone5:",
    ":revive:": ":moyai:",
    ":rhinoceros:": ":rhino:",
    ":rickshaw:": ":auto_rickshaw:",
    ":ride:": ":horse_racing:",
    ":rider:": ":horse_racing:",
    ":right:": ":point_right:",
    ":right_anger_bubble:": ":anger_right:",
    ":right_fist:": ":right_facing_fist:",
    ":right_fist_tone1:": ":right_facing_fist_tone1:",
    ":right_fist_tone2:": ":right_facing_fist_tone2:",
    ":right_fist_tone3:": ":right_facing_fist_tone3:",
    ":right_fist_tone4:": ":right_facing_fist_tone4:",
    ":right_fist_tone5:": ":right_facing_fist_tone5:",
    ":rise:": ":chart_with_upwards_trend:",
    ":river:": ":park:",
    ":ro:": ":flag_ro:",
    ":road:": ":motorway:",
    ":robber:": ":ninja:",
    ":robot_face:": ":robot:",
    ":rolled_up_newspaper:": ":newspaper2:",
    ":rolling_on_the_floor_laughing:": ":rofl:",
    ":roof:": ":hut:",
    ":round:": ":o:",
    ":rs:": ":flag_rs:",
    ":rubber:": ":wheel:",
    ":rubbish:": ":put_litter_in_its_place:",
    ":ruler:": ":straight_ruler:",
    ":run:": ":runner:",
    ":russian:": ":flag_ru:",
    ":rw:": ":flag_rw:",
    ":sad:": ":sob:",
    ":safety:": ":safety_vest:",
    ":sailor:": ":merperson:",
    ":salute:": ":saluting:",
    ":same:": ":dancers:",
    ":satisfied:": ":laughing:",
    ":saucer:": ":fork_knife_plate:",
    ":saudi:": ":flag_sa:",
    ":saudiarabia:": ":flag_sa:",
    ":sauropod:": ":dinosaur:",
    ":save:": ":moneybag:",
    ":say:": ":speech_balloon:",
    ":sb:": ":flag_sb:",
    ":sc:": ":flag_sc:",
    ":scale:": ":scales:",
    ":schoolbag:": ":school_satchel:",
    ":science:": ":telescope:",
    ":scientific:": ":telescope:",
    ":screen:": ":desktop:",
    ":screw:": ":nut_and_bolt:",
    ":sd:": ":flag_sd:",
    ":se:": ":flag_se:",
    ":sea:": ":ocean:",
    ":seafood:": ":oyster:",
    ":second:": ":stopwatch:",
    ":second_place_medal:": ":second_place:",
    ":see:": ":eyes:",
    ":seed:": ":seedling:",
    ":seller:": ":juggling:",
    ":send:": ":outbox_tray:",
    ":sew:": ":needle:",
    ":sg:": ":flag_sg:",
    ":sh:": ":flag_sh:",
    ":shadow:": ":waxing_crescent_moon:",
    ":shaking_hands:": ":handshake:",
    ":shaking_hands_tone1:": ":handshake_tone1:",
    ":shaking_hands_tone2:": ":handshake_tone2:",
    ":shaking_hands_tone3:": ":handshake_tone3:",
    ":shaking_hands_tone4:": ":handshake_tone4:",
    ":shaking_hands_tone5:": ":handshake_tone5:",
    ":shape:": ":large_orange_diamond:",
    ":sharp:": ":dagger:",
    ":she:": ":handball_girl:",
    ":shear:": ":scissors:",
    ":shelled_peanut:": ":peanuts:",
    ":shilling:": ":pound:",
    ":shine:": ":sunny:",
    ":shit:": ":poop:",
    ":shiver:": ":cold:",
    ":shoe:": ":athletic_shoe:",
    ":shop:": ":convenience_store:",
    ":shopkeeper:": ":man_with_beard:",
    ":shopping:": ":shopping_cart:",
    ":shopping_trolley:": ":shopping_cart:",
    ":short:": ":shorts:",
    ":shortcake:": ":cake:",
    ":shoulder:": ":shrug:",
    ":show:": ":point_right:",
    ":shutter:": ":camera_with_flash:",
    ":si:": ":flag_si:",
    ":sick:": ":nauseated_face:",
    ":sign:": ":writing_hand_tone1:",
    ":sign_of_the_horns:": ":metal:",
    ":sign_of_the_horns_tone1:": ":metal_tone1:",
    ":sign_of_the_horns_tone2:": ":metal_tone2:",
    ":sign_of_the_horns_tone3:": ":metal_tone3:",
    ":sign_of_the_horns_tone4:": ":metal_tone4:",
    ":sign_of_the_horns_tone5:": ":metal_tone5:",
    ":silver:": ":second_place:",
    ":sing:": ":microphone:",
    ":sister:": ":girl_tone1:",
    ":sit:": ":chair:",
    ":size:": ":straight_ruler:",
    ":sj:": ":flag_sj:",
    ":sk:": ":flag_sk:",
    ":skate:": ":roller_skate:",
    ":skeleton:": ":skull:",
    ":skirt:": ":dress:",
    ":skull_and_crossbones:": ":skull_crossbones:",
    ":sky:": ":milky_way:",
    ":sl:": ":flag_sl:",
    ":slaughter:": ":knife:",
    ":sleep:": ":sleeping:",
    ":sleuth_or_spy:": ":spy:",
    ":sleuth_or_spy_tone1:": ":spy_tone1:",
    ":sleuth_or_spy_tone2:": ":spy_tone2:",
    ":sleuth_or_spy_tone3:": ":spy_tone3:",
    ":sleuth_or_spy_tone4:": ":spy_tone4:",
    ":sleuth_or_spy_tone5:": ":spy_tone5:",
    ":slide:": ":playground_slide:",
    ":slightly_frowning_face:": ":slight_frown:",
    ":slightly_smiling_face:": ":slight_smile:",
    ":slipper:": ":thong_sandal:",
    ":slowly:": ":snail:",
    ":sm:": ":flag_sm:",
    ":small:": ":microscope:",
    ":small_airplane:": ":airplane_small:",
    ":smell:": ":nose:",
    ":smoke:": ":smoking:",
    ":sn:": ":flag_sn:",
    ":sneeze:": ":sneezing_face:",
    ":snow:": ":cloud_snow:",
    ":snow_capped_mountain:": ":mountain_snow:",
    ":snowstorm:": ":cloud_snow:",
    ":snowy:": ":cloud_snow:",
    ":sock:": ":socks:",
    ":soft:": ":teddy:",
    ":softly:": ":teddy:",
    ":soldier:": ":guardsman:",
    ":solicitor:": ":judge:",
    ":some:": ":pinched_fingers:",
    ":somebody:": ":bust_in_silhouette:",
    ":someone:": ":bust_in_silhouette:",
    ":something:": ":eyes:",
    ":son:": ":boy:",
    ":song:": ":musical_score:",
    ":sorry:": ":pleading:",
    ":soup:": ":stew:",
    ":sour:": ":stuck_out_tongue_closed_eyes:",
    ":southeast:": ":arrow_lower_right:",
    ":southwest:": ":arrow_lower_left:",
    ":space:": ":milky_way:",
    ":spark:": ":sparkles:",
    ":speak:": ":speaking_head:",
    ":speaking_head_in_silhouette:": ":speaking_head:",
    ":spectator:": ":mens:",
    ":spend:": ":money_with_wings:",
    ":spiral_calendar_pad:": ":calendar_spiral:",
    ":spiral_note_pad:": ":notepad_spiral:",
    ":sponsor:": ":mens:",
    ":sport:": ":runner:",
    ":sports_medal:": ":medal:",
    ":spring:": ":seedling:",
    ":square:": ":white_medium_square:",
    ":sr:": ":flag_sr:",
    ":ss:": ":flag_ss:",
    ":st:": ":flag_st:",
    ":stand:": ":person_standing_girl_tone1:",
    ":start:": ":clapper:",
    ":stay:": ":hand_splayed:",
    ":steamer:": ":cruise_ship:",
    ":stick:": ":hockey:",
    ":still:": ":mute:",
    ":stone:": ":rock:",
    ":stop:": ":octagonal_sign:",
    ":stop_sign:": ":octagonal_sign:",
    ":store:": ":department_store:",
    ":story:": ":book:",
    ":storybook:": ":books:",
    ":straight:": ":straight_ruler:",
    ":stranger:": ":bust_in_silhouette:",
    ":straw:": ":cup_with_straw:",
    ":street:": ":motorway:",
    ":strong:": ":muscle:",
    ":strongly:": ":muscle:",
    ":studio_microphone:": ":microphone2:",
    ":study:": ":technologist_woman_tone1:",
    ":stuffed_pita:": ":stuffed_flatbread:",
    ":subject:": ":books:",
    ":successor:": ":mens:",
    ":sugar:": ":candy:",
    ":summer:": ":sunny:",
    ":sun:": ":sun_with_face:",
    ":sunlight:": ":sunrise_over_mountains:",
    ":sunset:": ":city_sunset:",
    ":sunshine:": ":sunrise:",
    ":super:": ":superhero:",
    ":supermarket:": ":convenience_store:",
    ":supper:": ":fork_knife_plate:",
    ":sv:": ":flag_sv:",
    ":sweater:": ":yarn:",
    ":sweet:": ":lollipop:",
    ":swim:": ":swimmer:",
    ":swing:": ":golfer:",
    ":sx:": ":flag_sx:",
    ":sy:": ":flag_sy:",
    ":symbol:": ":symbols:",
    ":sz:": ":flag_sz:",
    ":t-shirt:": ":shirt:",
    ":ta:": ":flag_ta:",
    ":table_tennis:": ":ping_pong:",
    ":tail:": ":chipmunk:",
    ":tailor:": ":womens:",
    ":take:": ":bus:",
    ":talk:": ":speaking_head:",
    ":tall:": ":statue_of_liberty:",
    ":taller:": ":ladder:",
    ":tanker:": ":ship:",
    ":tap:": ":potable_water:",
    ":tape:": ":vhs:",
    ":taste:": ":yum:",
    ":tc:": ":flag_tc:",
    ":td:": ":flag_td:",
    ":teach:": ":teacher_woman_tone1:",
    ":team:": ":handshake:",
    ":technician:": ":technologist:",
    ":teenager:": ":boy:",
    ":tell:": ":speaking_head:",
    ":temple:": ":hindu_temple:",
    ":ten:": ":keycap_ten:",
    ":terror:": ":skull_crossbones:",
    ":textbook:": ":books:",
    ":tf:": ":flag_tf:",
    ":tg:": ":flag_tg:",
    ":th:": ":flag_th:",
    ":thank:": ":pray:",
    ":that:": ":point_right:",
    ":the:": ":point_right:",
    ":theatre:": ":classical_building:",
    ":their:": ":family_wwgg:",
    ":theirs:": ":family_wwgg:",
    ":them:": ":family_wwgg:",
    ":themselves:": ":family_wwgg:",
    ":then:": ":soon:",
    ":there:": ":point_down:",
    ":these:": ":index_pointing_at_the_viewer:",
    ":they:": ":family_wwgg:",
    ":thick:": ":ram:",
    ":thin:": ":pinching_hand:",
    ":thing:": ":shopping_bags:",
    ":think:": ":thinking:",
    ":thinking_face:": ":thinking:",
    ":third_place_medal:": ":third_place:",
    ":thirsty:": ":hot_face:",
    ":this:": ":index_pointing_at_the_viewer:",
    ":those:": ":information_desk_person:",
    ":thousand:": ":dollar:",
    ":three_button_mouse:": ":mouse_three_button:",
    ":throw:": ":handball:",
    ":thumbdown:": ":thumbsdown:",
    ":thumbdown_tone1:": ":thumbsdown_tone1:",
    ":thumbdown_tone2:": ":thumbsdown_tone2:",
    ":thumbdown_tone3:": ":thumbsdown_tone3:",
    ":thumbdown_tone4:": ":thumbsdown_tone4:",
    ":thumbdown_tone5:": ":thumbsdown_tone5:",
    ":thumbup:": ":thumbsup:",
    ":thumbup_tone1:": ":thumbsup_tone1:",
    ":thumbup_tone2:": ":thumbsup_tone2:",
    ":thumbup_tone3:": ":thumbsup_tone3:",
    ":thumbup_tone4:": ":thumbsup_tone4:",
    ":thumbup_tone5:": ":thumbsup_tone5:",
    ":thunder:": ":cloud_lightning:",
    ":thunder_cloud_and_rain:": ":thunder_cloud_rain:",
    ":tidy:": ":broom:",
    ":timber:": ":wood:",
    ":time:": ":watch:",
    ":timer_clock:": ":timer:",
    ":timetable:": ":calendar_spiral:",
    ":tin:": ":canned_food:",
    ":tired:": ":yawning:",
    ":tj:": ":flag_tj:",
    ":tk:": ":flag_tk:",
    ":tl:": ":flag_tl:",
    ":tn:": ":flag_tn:",
    ":to:": ":arrow_right:",
    ":today:": ":calendar:",
    ":together:": ":handshake:",
    ":tomorrow:": ":calendar:",
    ":tone:": ":musical_note:",
    ":too:": ":exclamation:",
    ":tool:": ":tools:",
    ":toothache:": ":tooth:",
    ":toothless:": ":tooth:",
    ":torch:": ":flashlight:",
    ":touch:": ":point_up_2:",
    ":tourist:": ":mens:",
    ":tower:": ":tokyo_tower:",
    ":toy:": ":teddy:",
    ":tr:": ":flag_tr:",
    ":transfer:": ":arrows_counterclockwise:",
    ":travel:": ":map:",
    ":tree:": ":evergreen_tree:",
    ":triangle:": ":triangular_ruler:",
    ":trousers:": ":jeans:",
    ":try:": ":test_tube:",
    ":tt:": ":flag_tt:",
    ":tube:": ":test_tube:",
    ":turkmenistan:": ":flag_tm:",
    ":turn:": ":arrows_counterclockwise:",
    ":turnover:": ":arrows_counterclockwise:",
    ":tutor:": ":teacher_tone1:",
    ":tuvalu:": ":flag_tv:",
    ":tuxedo_tone1:": ":man_in_tuxedo_tone1:",
    ":tuxedo_tone2:": ":man_in_tuxedo_tone2:",
    ":tuxedo_tone3:": ":man_in_tuxedo_tone3:",
    ":tuxedo_tone4:": ":man_in_tuxedo_tone4:",
    ":tuxedo_tone5:": ":man_in_tuxedo_tone5:",
    ":tw:": ":flag_tw:",
    ":twice:": ":two_hearts:",
    ":twin:": ":two_women_holding_hands:",
    ":typewriter:": ":card_index:",
    ":typhoon:": ":cyclone:",
    ":typist:": ":technologist:",
    ":tyre:": ":wheel:",
    ":tz:": ":flag_tz:",
    ":ua:": ":flag_ua:",
    ":ufo:": ":flying_saucer:",
    ":ug:": ":flag_ug:",
    ":ugly:": ":zombie:",
    ":um:": ":flag_um:",
    ":umbrella_on_ground:": ":beach_umbrella:",
    ":uncle:": ":man_with_beard:",
    ":underground:": ":metro:",
    ":unhappy:": ":unamused:",
    ":unhealthy:": ":microbe:",
    ":unicorn_face:": ":unicorn:",
    ":university:": ":school:",
    ":unlike:": ":thumbsdown:",
    ":until:": ":clock1:",
    ":unusually:": ":alien:",
    ":up:": ":point_up:",
    ":upside_down_face:": ":upside_down:",
    ":upwards:": ":chart_with_upwards_trend:",
    ":us:": ":family_mwb:",
    ":use:": ":hammer_pick:",
    ":useful:": ":tools:",
    ":user:": ":bust_in_silhouette:",
    ":uy:": ":flag_uy:",
    ":uz:": ":flag_uz:",
    ":va:": ":flag_va:",
    ":vase:": ":amphora:",
    ":vc:": ":flag_vc:",
    ":ve:": ":flag_ve:",
    ":vegetable:": ":leafy_green:",
    ":vegetation:": ":leafy_green:",
    ":versus:": ":vs:",
    ":very:": ":cool:",
    ":vest:": ":safety_vest:",
    ":veteran:": ":pilot:",
    ":veto:": ":no_entry_sign:",
    ":vg:": ":flag_vg:",
    ":vi:": ":flag_vi:",
    ":victory:": ":v:",
    ":village:": ":houses:",
    ":vinegar:": ":beverage_box:",
    ":virus:": ":microbe:",
    ":visit:": ":airplane_arriving:",
    ":visitor:": ":mens:",
    ":vn:": ":flag_vn:",
    ":voice:": ":loud_sound:",
    ":volt:": ":zap:",
    ":voltage:": ":zap:",
    ":vote:": ":ballot_box:",
    ":vu:": ":flag_vu:",
    ":wait:": ":hourglass_flowing_sand:",
    ":waiter:": ":woman_in_tuxedo:",
    ":walk:": ":walking:",
    ":wallet:": ":purse:",
    ":want:": ":pleading:",
    ":warm-up:": ":fire:",
    ":warm:": ":hotsprings:",
    ":wash:": ":shower:",
    ":water:": ":potable_water:",
    ":waving_black_flag:": ":flag_black:",
    ":waving_white_flag:": ":flag_white:",
    ":way:": ":motorway:",
    ":we:": ":family_mwb:",
    ":wear:": ":sari:",
    ":weather:": ":white_sun_rain_cloud:",
    ":web:": ":spider_web:",
    ":week:": ":calendar_spiral:",
    ":weekday:": ":calendar_spiral:",
    ":weekend:": ":tada:",
    ":weekly:": ":date:",
    ":weigh:": ":scales:",
    ":weight:": ":scales:",
    ":weight_lifter:": ":lifter:",
    ":weight_lifter_tone1:": ":lifter_tone1:",
    ":weight_lifter_tone2:": ":lifter_tone2:",
    ":weight_lifter_tone3:": ":lifter_tone3:",
    ":weight_lifter_tone4:": ":lifter_tone4:",
    ":weight_lifter_tone5:": ":lifter_tone5:",
    ":welcome:": ":hugging:",
    ":weld:": ":factory_worker_woman_tone1:",
    ":well-known:": ":superhero:",
    ":well:": ":ok_hand:",
    ":western:": ":mrs_claus:",
    ":wf:": ":flag_wf:",
    ":what:": ":question:",
    ":whatever:": ":shrug:",
    ":when:": ":question:",
    ":where:": ":question:",
    ":which:": ":question:",
    ":whisky:": ":tumbler_glass:",
    ":white:": ":white_heart:",
    ":white_frowning_face:": ":frowning2:",
    ":white_sun_behind_cloud:": ":white_sun_cloud:",
    ":white_sun_behind_cloud_with_rain:": ":white_sun_rain_cloud:",
    ":white_sun_with_small_cloud:": ":white_sun_small_cloud:",
    ":who:": ":bust_in_silhouette:",
    ":whoever:": ":bust_in_silhouette:",
    ":whom:": ":question:",
    ":whose:": ":question:",
    ":why:": ":question:",
    ":wife:": ":pregnant_woman_tone1:",
    ":wild:": ":boar:",
    ":wilted_flower:": ":wilted_rose:",
    ":win:": ":trophy:",
    ":wind-bell:": ":bell:",
    ":wind:": ":cloud_tornado:",
    ":windmill:": ":ferris_wheel:",
    ":windy:": ":cloud_tornado:",
    ":wine:": ":wine_glass:",
    ":winner:": ":trophy:",
    ":winter:": ":snowman2:",
    ":wish:": ":pray:",
    ":with:": ":handshake:",
    ":wonderful:": ":smiling_face_with_hearts:",
    ":woof:": ":dog2:",
    ":wool:": ":yarn:",
    ":word:": ":speech_balloon:",
    ":work:": ":briefcase:",
    ":worker:": ":mechanic:",
    ":workman:": ":factory_worker:",
    ":world:": ":earth_africa:",
    ":world_map:": ":map:",
    ":worry:": ":worried:",
    ":worship:": ":place_of_worship:",
    ":worship_symbol:": ":place_of_worship:",
    ":wreath:": ":white_flower:",
    ":wrestling:": ":wrestlers:",
    ":wrestling_tone1:": ":wrestlers_tone1:",
    ":wrestling_tone2:": ":wrestlers_tone2:",
    ":wrestling_tone3:": ":wrestlers_tone3:",
    ":wrestling_tone4:": ":wrestlers_tone4:",
    ":wrestling_tone5:": ":wrestlers_tone5:",
    ":wrinkle:": ":older_woman:",
    ":write:": ":writing_hand:",
    ":writer:": ":technologist_woman_tone1:",
    ":writing:": ":pencil:",
    ":wrong:": ":x:",
    ":ws:": ":flag_ws:",
    ":xk:": ":flag_xk:",
    ":yacht:": ":motorboat:",
    ":yard:": ":house_with_garden:",
    ":yawn:": ":yawning:",
    ":ye:": ":flag_ye:",
    ":year:": ":calendar_spiral:",
    ":yellow:": ":yellow_heart:",
    ":yes:": ":ok_woman_tone1:",
    ":yesterday:": ":calendar:",
    ":you:": ":technologist:",
    ":young:": ":baby:",
    ":your:": ":technologist:",
    ":yours:": ":technologist:",
    ":yourself:": ":technologist:",
    ":youth:": ":boy_tone1:",
    ":yt:": ":flag_yt:",
    ":za:": ":flag_za:",
    ":zipper_mouth_face:": ":zipper_mouth:",
    ":zm:": ":flag_zm:",
    ":zoo:": ":lion_face:",
    ":zw:": ":flag_zw:",
}
